Module random

Module random 

Structs

RandomCharBuilder
A random String builder, providig fined-grained control over what a random String should contain.
RandomStringBuilder
A random String builder, providig fined-grained control over what a random String should contain.

Traits

CharBuilder

Functions

bool
Get a random bool value with a probability of 50%
get_boolDeprecated
Get a random boolean value
get_charDeprecated
get_int
Get a random number (i32) from a minimum and maximum value
get_letterDeprecated
Get a random char from a-z or A-Z
get_stringDeprecated
Get a random string with a given length and a set of characters
get_symbol
Get a random symbol from a list of symbols Possible symbols are: #, $, %, &, *, @, ^
number
Get a random number within a range